/*!
 * \file condition.h
 * \brief A condition object to store information on a condition entry in the RMS.
 *
 * A condition object to store information on a condition entry in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef CONDITION_H_
#define CONDITION_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \class study
 * \brief A condition object to store information on a condition entry in the RMS.
 *
 * A condition object to store information on a condition entry in the RMS.
 */
class condition
{
public:
  /*!
   * Create a condition with the given information.
   *
   * @param condid the condition ID number
   * @param studyid the study ID number this condition belongs to
   * @param name the name of the condition
   * @param intid the interface ID number for this condition
   */
  condition(int condid, int studyid, std::string name, int intid);

  /*!
   * Get the condition ID number.
   *
   * @return the condition ID number
   */
  int get_condid();
  /*!
   * Get the study ID number this condition belongs to.
   *
   * @return the study ID number this condition belongs to
   */
  int get_studyid();
  /*!
   * Get the name of the condition.
   *
   * @return the name of the condition
   */
  std::string get_name();
  /*!
   * Get the interface ID number for this condition.
   *
   * @return the interface ID number for this condition
   */
  int get_intid();

private:
  int condid, studyid, intid; /*!< the condition, study, and interface ID numbers */
  std::string name; /*!< the name of the condition */
};
}

#endif
