/*!
 * \file user_account.h
 * \brief A user account object to store information on a user in the RMS.
 *
 * A user account object to store information on a user in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef USERACCOUNT_H_
#define USERACCOUNT_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \enum USER_ACCOUNT_TYPE
 * The different types of users in the RMS.
 */
enum USER_ACCOUNT_TYPE
{
  ADMIN, USER
};

/*!
 * \class user_account
 * \brief A user account object to store information on a user in the RMS.
 *
 * A user account object to store information on a user in the RMS.
 */
class user_account
{
public:
  /*!
   * Creates a user account object with the given information.
   *
   * @param uid the user ID of the user
   * @param username the username of the user
   * @param fname the firstname of the user
   * @param lname the lastname of the user
   * @param email the email of the user
   * @param type the type of user (e.g., admin, user)
   */
  user_account(int uid, std::string username, std::string fname, std::string lname,
               std::string email, rms::USER_ACCOUNT_TYPE type);

  /*!
   * Get the user ID of the user.
   * @return the user ID of the user
   */
  int get_userid();
  /*!
   * Get the username of the user.
   * @return the username of the user
   */
  std::string get_username();
  /*!
   * Get the firstname of the user.
   * @return the firstname of the user
   */
  std::string get_firstname();
  /*!
   * Get the lastname of the user.
   * @return the lastname of the user
   */
  std::string get_lastname();
  /*!
   * Get the email of the user.
   * @return the email of the user
   */
  std::string get_email();
  /*!
   * Get the type of the user.
   * @return the type of the user
   */
  rms::USER_ACCOUNT_TYPE get_type();

private:
  int uid; /*!< the user ID */
  std::string username, fname, lname, email; /*!< the username, first and last names and email  */
  rms::USER_ACCOUNT_TYPE type; /*!< the type of user the */
};
}

#endif
